==> apache-camel-3.2.0-src.zip: apache-camel-3.2.0/core/camel-core/src/test/java/org/apache/camel/processor/onexception/OnExceptionWireTapNewExchangeBodyTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor.onexception;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.junit.Test;

public class OnExceptionWireTapNewExchangeBodyTest extends ContextTestSupport {

    @Test
    public void testOnExceptionWireTapNewExchangeBody() throws Exception {
        getMockEndpoint("mock:tap").expectedBodiesReceived("Error due Forced");
        getMockEndpoint("mock:ignore").expectedMessageCount(1);

        template.sendBody("direct:start", "Hello World");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                onException(IllegalArgumentException.class).wireTap("mock:tap").newExchangeBody(simple("Error due ${exception.message}")).end().handled(true).to("mock:ignore");

                from("direct:start").throwException(new IllegalArgumentException("Forced"));
            }
        };
    }
}

==> apache-camel-3.4.0-src.zip: apache-camel-3.4.0/core/camel-core/src/test/java/org/apache/camel/processor/onexception/OnExceptionWireTapNewExchangeBodyTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor.onexception;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

public class OnExceptionWireTapNewExchangeBodyTest extends ContextTestSupport {

    @Test
    public void testOnExceptionWireTapNewExchangeBody() throws Exception {
        getMockEndpoint("mock:tap").expectedBodiesReceived("Error due Forced");
        getMockEndpoint("mock:ignore").expectedMessageCount(1);

        template.sendBody("direct:start", "Hello World");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                onException(IllegalArgumentException.class).wireTap("mock:tap").newExchangeBody(simple("Error due ${exception.message}")).end().handled(true).to("mock:ignore");

                from("direct:start").throwException(new IllegalArgumentException("Forced"));
            }
        };
    }
}
